@@ -4,6 +4,26 @@ import copy
 from datetime import datetime
 
 
+def get_error(method, *args, **kwargs):
+    error_string = ""
+
+    if "statusCode" in kwargs:
+        if "URL" in kwargs:
+            error_string += "\nURL: {}".format(kwargs["URL"])
+
+        if "payload" in kwargs:
+            error_string += "\nPayload: {}".format(kwargs["payload"])
+
+        error_string += "\nstatusCode: {}".format(kwargs["statusCode"])
+        error_string += "\nBody: {}".format(kwargs["body"])
+
+    else:
+        for i in args:
+            error_string += "\n{}".format(i)
+
+    raise SystemExit("{} ERROR:\n{}".format(method.upper(), error_string))
+
+
 def get_response(code, body):
     if type(body) in [dict, list]:
         return {
@@ -16,6 +36,7 @@ def get_response(code, body):
             "body": body
         }
 
+
 def get_config():
     with open(os.path.dirname(__file__) + "/../config.json", "r") as read_file:
         config = json.load(read_file)
